"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.writeUi5RepositoryFiles = exports.writeUi5RepositoryFile = exports.addUi5Dependency = void 0;
const path_1 = require("path");
const fast_glob_1 = __importDefault(require("fast-glob"));
const os_1 = require("os");
const project_access_1 = require("@sap-ux/project-access");
const constants_1 = require("./constants");
const semver_1 = require("semver");
/**
 * Adds a new UI5 dependency to the package.json.
 * No longer required for `@ui5/cli` v3 and above.
 *
 * @param fs - the memfs editor instance
 * @param basePath - the base path
 * @param depName - the dependency name
 */
function addUi5Dependency(fs, basePath, depName) {
    var _a, _b, _c, _d;
    const filePath = (0, path_1.join)(basePath, project_access_1.FileName.Package);
    const packageJson = ((_a = fs.readJSON(filePath)) !== null && _a !== void 0 ? _a : {});
    const ui5CliVersion = (0, semver_1.coerce)((_b = packageJson === null || packageJson === void 0 ? void 0 : packageJson.devDependencies) === null || _b === void 0 ? void 0 : _b[constants_1.UI5_CLI_LIB]);
    if (ui5CliVersion && (0, semver_1.satisfies)(ui5CliVersion, `>=${constants_1.UI5_CLI_MIN_VERSION}`)) {
        // https://sap.github.io/ui5-tooling/v3/updates/migrate-v3/#changes-to-dependency-configuration
        return;
    }
    packageJson.ui5 = (_c = packageJson.ui5) !== null && _c !== void 0 ? _c : {};
    packageJson.ui5.dependencies = (_d = packageJson.ui5.dependencies) !== null && _d !== void 0 ? _d : [];
    if (!packageJson.ui5.dependencies.includes(depName)) {
        packageJson.ui5.dependencies.push(depName);
    }
    fs.writeJSON(filePath, packageJson);
}
exports.addUi5Dependency = addUi5Dependency;
/**
 * Writes the UI5 repository file.
 *
 * @param fs - the memfs editor instance
 * @param basePath - the base path
 * @param ui5RepositoryFile - the UI5 repository file
 * @param addContent - the content to be added
 */
const writeUi5RepositoryFile = (fs, basePath, ui5RepositoryFile, addContent) => {
    const filePath = (0, path_1.join)(basePath, ui5RepositoryFile);
    let content;
    if (fs.exists(filePath)) {
        content = fs.read(filePath);
        if (!content.includes(addContent)) {
            content = `${content}\n${addContent}`;
        }
    }
    else {
        content = addContent;
    }
    fs.write(filePath, content);
};
exports.writeUi5RepositoryFile = writeUi5RepositoryFile;
/**
 * Writes the UI5 repository files if typescript files are found.
 *
 * @param fs - the memfs editor instance
 * @param basePath - the base path
 */
const writeUi5RepositoryFiles = (fs, basePath) => __awaiter(void 0, void 0, void 0, function* () {
    const webappPath = yield (0, project_access_1.getWebappPath)(basePath);
    const typescriptPattern = (0, path_1.join)(webappPath, '/**/*.ts');
    const normalisedPath = (0, os_1.platform)() === 'win32' ? typescriptPattern.replace(/\\/g, '/') : typescriptPattern;
    const typeScriptFilesPaths = yield (0, fast_glob_1.default)(normalisedPath);
    if ((typeScriptFilesPaths === null || typeScriptFilesPaths === void 0 ? void 0 : typeScriptFilesPaths.length) > 0) {
        (0, exports.writeUi5RepositoryFile)(fs, webappPath, constants_1.UI5_REPO_TEXT_FILES, '^.*.ts$');
    }
});
exports.writeUi5RepositoryFiles = writeUi5RepositoryFiles;
//# sourceMappingURL=file.js.map